@@ -60,14 +60,14 @@ After=network.target
 
 [Service]
 Type=simple
-ExecStart=/sbin/runuser -l nobody -c "/usr/bin/python -m advhttpsrv -c /etc/pyhttpd.conf"
+ExecStart=/sbin/runuser -l nobody -c "/usr/bin/python -m advancedhttpserver -c /etc/pyhttpd.conf"
 ExecStop=/bin/kill -INT $MAINPID
 
 [Install]
 WantedBy=multi-user.target
 """
 
-__version__ = '2.0.11'
+__version__ = '2.1.0'
 __all__ = (
 	'AdvancedHTTPServer',
 	'RegisterPath',
@@ -75,6 +75,7 @@ __all__ = (
 	'RPCClient',
 	'RPCClientCached',
 	'RPCError',
+	'RPCConnectionError',
 	'ServerTestCase',
 	'WebSocketHandler',
 	'build_server_from_argparser',
@@ -465,7 +466,7 @@ class RPCError(Exception):
 	This class represents an RPC error either local or remote. Any errors
 	in routines executed on the server will raise this error.
 	"""
-	def __init__(self, message, status, remote_exception=None):
+	def __init__(self, message, status=None, remote_exception=None):
 		super(RPCError, self).__init__()
 		self.message = message
 		self.status = status
@@ -489,6 +490,15 @@ class RPCError(Exception):
 		"""
 		return bool(self.remote_exception is not None)
 
+class RPCConnectionError(RPCError):
+	"""
+	An exception raised when there is a connection-related error encountered by
+	the RPC client.
+
+	.. versionadded:: 2.1.0
+	"""
+	pass
+
 class RPCClient(object):
 	"""
 	This object facilitates communication with remote RPC methods as
@@ -596,7 +606,7 @@ class RPCClient(object):
 				self.client.request('RPC', method, options, headers)
 				resp = self.client.getresponse()
 		except http.client.ImproperConnectionState:
-			raise RPCError('improper connection state', None)
+			raise RPCConnectionError('improper connection state')
 		if resp.status != 200:
 			raise RPCError(resp.reason, resp.status)
 
@@ -732,7 +742,7 @@ class ServerNonThreaded(http.server.HTTPServer, object):
 		except queue.Empty:
 			return self.handle_timeout()
 		except OSError:
-			return
+			return None
 
 		if self.verify_request(request, client_address):
 			try:
@@ -745,6 +755,7 @@ class ServerNonThreaded(http.server.HTTPServer, object):
 				raise
 		else:
 			self.shutdown_request(request)
+		return None
 
 	def finish_request(self, request, client_address):
 		try:
@@ -821,9 +832,9 @@ class RequestHandler(http.server.BaseHTTPRequestHandler, object):
 		self.headers_active = False
 		"""Whether or not the request is in the sending headers phase."""
 		self.handler_map = {}
-		"""The dict object which maps regular expressions of resources to the functions which should handle them."""
+		"""The dictionary object which maps regular expressions of resources to the functions which should handle them."""
 		self.rpc_handler_map = {}
-		"""The dict object which maps regular expressions of RPC functions to their handlers."""
+		"""The dictionary object which maps regular expressions of RPC functions to their handlers."""
 		for map_name in (None, self.__class__.__name__):
 			handler_map = g_handler_map.get(map_name, {})
 			for path, function_info in handler_map.items():
@@ -891,7 +902,7 @@ class RequestHandler(http.server.BaseHTTPRequestHandler, object):
 			file_obj = open(file_path, 'rb')
 		except IOError:
 			self.respond_not_found()
-			return None
+			return
 		self.send_response(200)
 		self.send_header('Content-Type', self.guess_mime_type(file_path))
 		fs = os.fstat(file_obj.fileno())
@@ -917,7 +928,7 @@ class RequestHandler(http.server.BaseHTTPRequestHandler, object):
 			dir_contents = os.listdir(dir_path)
 		except os.error:
 			self.respond_not_found()
-			return None
+			return
 		if os.path.normpath(dir_path) != self.__config['serve_files_root']:
 			dir_contents.append('..')
 		dir_contents.sort(key=lambda a: a.lower())
